from setuptools import setup

setup(name='pds_nds_p',
      version='0.1',
      description='Gaussian distributions',
      author="Mohamed Javeed",
      author_email='javeedrstar5@gmail.com',
      packages=['pds_nds_p'],
      zip_safe=False)
